import { defineConfig } from 'vite';

export default defineConfig({
  server: {
    cors: true,
    configureServer(server) {
      server.middlewares.use((req, res, next) => {
        if (req.url && req.url.startsWith('/data/')) {
          // Use mime-types to get the proper Content-Type
          const type = mime.lookup(req.url) || 'application/xml';
          res.setHeader('Content-Type', type);
        }
        next();
      });
    }
  },
  resolve: {
    alias: {
      events: 'events'
    }
  },
  optimizeDeps: {
    esbuildOptions: {
      define: { global: 'globalThis' }
    }
  },
  build: {
    lib: {
      entry: 'src/app.js',
      name: 'DccViewer',
      fileName: (format) => `dccviewer-js.${format}.js`
    },
    rollupOptions: {
      // Optionally mark dependencies as external if you don't want them bundled:
      // external: ['xml2js', 'plotly.js-dist', 'jsoneditor', 'dsiunits-js', 'events'],
    }
  }
});
